@@ -41,7 +41,8 @@ class BHunters(Karton):
                 }
             )
         self.send_discord_webhook(f"{self.identity} Started processing {url}",f"Status {status}","status")     
-
+        if status=="failed":
+            raise Exception(f"Failed to process {url}")
         
     def is_string(self,var):
         return isinstance(var, str)
@@ -130,6 +131,7 @@ class BHunters(Karton):
             "Content-Type": "application/json"
         }
         response = requests.post(webhook_url, data=json.dumps(data), headers=headers)
+        
 
 
     def monogocon(self):
@@ -167,4 +169,4 @@ class BHunters(Karton):
             hash_object = hashlib.md5(url_or_path.encode())
             safe_name = hash_object.hexdigest()
         
-        return safe_name
\ No newline at end of file
+        return safe_name
